@@ -18,6 +18,10 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE. --]]
 
+corsixth.require("announcer")
+
+local AnnouncementPriority = _G["AnnouncementPriority"]
+
 class "Hospital"
 
 ---@type Hospital
@@ -47,7 +51,6 @@ function Hospital:Hospital(world, avail_rooms, name)
   self.acc_research_cost = 0
   self.acc_overdraft = 0
   self.acc_heating = 0
-  self.discover_autopsy_risk = 10
 
   -- The sum of all material values (tiles, rooms, objects).
   -- Initial value: hospital tile count * tile value + 20000
@@ -658,6 +661,11 @@ function Hospital:afterLoad(old, new)
     self.ratholes = {}
   end
 
+  if old < 131 then
+    self.autopsy_discovered = nil
+    self.discover_autopsy_risk = nil
+  end
+
   -- Update other objects in the hospital (added in version 106).
   if self.epidemic then self.epidemic.afterLoad(old, new) end
   for _, future_epidemic in ipairs(self.future_epidemics_pool) do
@@ -688,7 +696,7 @@ function Hospital:countSittingStanding()
   local numberStanding = 0
   for _, patient in ipairs(self.patients) do
     local pat_action = patient:getCurrentAction()
-    if pat_action.name == "idle" then
+    if pat_action.name == "idle" and not patient:getRoom() then
       numberStanding = numberStanding + 1
     elseif pat_action.name == "use_object" and pat_action.object.object_type.id == "bench" then
       numberSitting = numberSitting + 1
@@ -881,7 +889,7 @@ function Hospital:coldWarning()
     "sorry002.wav", "sorry004.wav",
   }
   if announcements and self:isPlayerHospital() then
-    self.world.ui:playAnnouncement(announcements[math.random(1, #announcements)])
+    self.world.ui:playAnnouncement(announcements[math.random(1, #announcements)], AnnouncementPriority.Normal)
   end
 end
 function Hospital:hotWarning()
@@ -889,7 +897,7 @@ function Hospital:hotWarning()
     "sorry003.wav", "sorry004.wav",
   }
   if announcements and self:isPlayerHospital() then
-    self.world.ui:playAnnouncement(announcements[math.random(1, #announcements)])
+    self.world.ui:playAnnouncement(announcements[math.random(1, #announcements)], AnnouncementPriority.Normal)
   end
 end
 -- Called when the hospitals's boiler has broken down.
@@ -1222,9 +1230,11 @@ function Hospital:createEmergency(emergency)
     if self:hasRoomOfType(emergency.disease.treatment_rooms[no_rooms]) then
       room_name = nil
     end
-    local added_info = _S.fax.emergency.cure_possible
-    -- TODO: Differentiate if a drug is needed, add drug effectiveness. Add undiscovered treatment.
-    -- added_info = _S.fax.emergency.cure_not_possible
+
+    local casebook = self.disease_casebook[random_disease.id]
+    local added_info = casebook.drug and
+        _S.fax.emergency.cure_possible_drug_name_efficiency:format(emergency.disease.name, casebook.cure_effectiveness)
+        or _S.fax.emergency.cure_possible
     if room_name then
       if staff_available then
         added_info = _S.fax.emergency.cure_not_possible_build:format(room_name) .. "."
@@ -1251,7 +1261,7 @@ function Hospital:createEmergency(emergency)
         {text = _S.fax.emergency.choices.refuse, choice = "refuse_emergency"},
       },
     }
-    self.world.ui.bottom_panel:queueMessage("emergency", message, nil, 24*20, 2) -- automatically refuse after 20 days
+    self.world.ui.bottom_panel:queueMessage("emergency", message, nil, Date.hoursPerDay() * 16, 2) -- automatically refuse after 16 days
     created_one = true
   end
   return created_one
@@ -1668,7 +1678,7 @@ function Hospital:initStaff()
         added_staff = false
       end
       if added_staff then
-        local staff = self.world:newEntity("Staff", 2)
+        local staff = self.world:newEntity(profile.humanoid_class, 2)
         staff:setProfile(profile)
         -- TODO: Make a somewhat "nicer" placing algorithm.
         staff:setTile(self.world.map.th:getCameraTile(1))
@@ -1685,6 +1695,7 @@ function Hospital:addStaff(staff)
   self.staff[#self.staff + 1] = staff
   -- Cost of hiring staff:
   self:spendMoney(staff.profile.wage, _S.transactions.hire_staff .. ": " .. staff.profile.name)
+  self:notifyOfStaffChange(staff)
 end
 
 function Hospital:addPatient(patient)
@@ -1760,6 +1771,8 @@ end
 --!param staff (Staff) Staff member to remove.
 function Hospital:removeStaff(staff)
   RemoveByValue(self.staff, staff)
+  -- update all messages for waiting patients
+  self:notifyOfStaffChange(staff)
 end
 
 --! Remove a patient from the hospital.
@@ -1912,8 +1925,9 @@ function Hospital:getAveragePatientAttribute(attribute, default_value)
   local sum = 0
   local count = 0
   for _, patient in ipairs(self.patients) do
+    local tx, ty = patient.tile_x, patient.tile_y
     -- Some patients (i.e. Alien) may not have the attribute in question, so check for that
-    if patient.attributes[attribute] then
+    if tx and ty and self:isInHospital(tx, ty) and patient.attributes[attribute] then
       sum = sum + patient.attributes[attribute]
       count = count + 1
     end
@@ -2204,13 +2218,13 @@ function Hospital:searchForHandymanTask(handyman, taskType)
     if canContinue then
       if v.assignedHandyman then
         if v.assignedHandyman.fired then
-          v.assignedHandyman = nil
+          v.assignedHandyman:unassignTask()
         elseif not v.assignedHandyman.hospital then
           -- This should normally never be the case. If the handyman doesn't belong to a hsopital
           -- then they should not have any tasks assigned to them however it was previously possible
           -- We need to tidy up to make sure the task can be reassigned.
           print("Warning: Orphaned handyman is still assigned a task. Removing.")
-          v.assignedHandyman = nil
+          v.assignedHandyman:unassignTask()
         else
           local assignedDistance = self.world:getPathDistance(v.tile_x, v.tile_y, v.assignedHandyman.tile_x, v.assignedHandyman.tile_y)
           if assignedDistance ~= false then
@@ -2355,3 +2369,11 @@ function Hospital:computePriceLevelImpact(patient, casebook)
     self.world.ui.adviser:say(_A.warnings.fair_prices:format(casebook.disease.name))
   end
 end
+
+--! Notify patients of a change to hospital staff members
+--!param staff (Staff) Changed staff member subject of notification
+function Hospital:notifyOfStaffChange(staff)
+  for _, patient in pairs(self.patients) do
+    patient:notifyOfStaffChange(staff)
+  end
+end
