@@ -47,6 +47,8 @@ function Window:Window()
   }
   self.textboxes = { -- list of textboxes in that window. NB: (Game)UI also uses this.
   }                  -- Take care not to handle things twice as UI is subclass of window!
+  self.hotkeyboxes = {
+  }
   self.key_handlers = {--[[a set]]}
   self.windows = false -- => {} when first window added
   self.active_button = false
@@ -123,6 +125,9 @@ function Window:close()
   for _, box in pairs(self.textboxes) do
     self.ui:unregisterTextBox(box)
   end
+  for _, box in pairs(self.hotkeyboxes) do
+    self.ui:unregisterHotkeyBox(box)
+  end
   self.closed = true
 end
 
@@ -183,6 +188,10 @@ function Panel:makeTextbox(...)
   return self.window:makeTextboxOnPanel(self, ...)
 end
 
+function Panel:makeHotkeyBox(...)
+  return self.window:makeHotkeyBoxOnPanel(self, ...)
+end
+
 local function sanitize(colour)
   if colour > 255 then
     colour = 255
@@ -1282,6 +1291,166 @@ function Window:makeTextboxOnPanel(panel, confirm_callback, abort_callback)
   return textbox
 end
 
+--! A window element used to accept hotkey configurations.
+class "HotkeyBox"
+
+---@type HotkeyBox
+local HotkeyBox = _G["HotkeyBox"]
+
+--!dummy
+function HotkeyBox:HotkeyBox()
+  self.panel = nil
+  self.confirm_callback = nil
+  self.abort_callback = nil
+  self.button = nil
+  self.text = nil
+  self.allowed_input = nil
+  self.char_limit = nil
+  self.visible = nil
+  self.enabled = nil
+  self.active = nil
+  self.noted_keys = {}
+end
+
+local hotkeybox_mt = permanent("Window.<hotkeybox_mt>", getmetatable(HotkeyBox()))
+
+--! Set the box to not active and run confirm callback, if any
+function HotkeyBox:confirm()
+  self:setActive(false)
+  if self.confirm_callback then
+    self.confirm_callback()
+  end
+  self.noted_keys = {}
+end
+
+--! Set the box to not active and run abort callback, if any
+function HotkeyBox:abort()
+  self:setActive(false)
+  if self.abort_callback then
+    self.abort_callback()
+  end
+  self.noted_keys = {}
+end
+
+--! Set the hotkeybox active status to true or false, taking care of any
+-- additional things that need to be done: deactivate any other hotkeyboxes,
+-- handle blinking cursor, keyboard repeat on/off, set button state accordingly
+--!param active (boolean) whether to activate (true) or deactivate (false) the box
+function HotkeyBox:setActive(active)
+  local ui = self.panel.window.ui
+  if active then
+    -- Unselect any other hotkeybox
+    for _, hotkeybox in ipairs(ui.hotkeyboxes) do
+      if hotkeybox ~= self and hotkeybox.active then
+        hotkeybox:abort()
+      end
+    end
+
+    -- Update text
+    self.panel:setLabel(self.text)
+  end
+
+  self.active = active
+  -- Update button if necessary
+  if self.button.toggled ~= active then
+    self.button:toggle()
+  end
+end
+
+function HotkeyBox:clicked()
+  local active = self.button.toggled
+  if active then
+    self:setActive(true)
+  else
+    if self.text == "" then
+      self:abort()
+    else
+      self:confirm()
+    end
+  end
+end
+
+function HotkeyBox:keyInput(char, rawchar, modifiers)
+  if not self.active then
+    return false
+  end
+  -- Just return true so any key's we press aren't passed to anything else.
+  return true
+end
+
+--[[ Limit input handled by textbox to specific classes of characters
+!param types (string or table) One of, or an table of any number of input types
+! valid input types are:
+!  "alpha": Letters (lower and uppercase)
+!  "numbers": 0-9
+!  "misc": other characters, currently space and hyphen
+!  "all": experimental category that allows, theoretically, all input
+]]
+function HotkeyBox:allowedInput(types)
+  if type(types) ~= "table" then types = {types} end
+  self.allowed_input = {}
+  for _, t in ipairs(types) do
+    self.allowed_input[t] = true
+  end
+  return self
+end
+
+--[[ Set the text of the textbox to a given string or list of strings.
+! Use empty string to make textbox a single line textbox (default).
+! Use table with empty string {""} to make it a multiline textbox.
+!param text (string or table) The string or list of strings the textbox should contain.
+]]
+function HotkeyBox:setText(text)
+  self.text = text
+  self.panel:setLabel(self.text)
+  return self
+end
+
+function HotkeyBox:setPosition(x, y)
+  self.button:setPosition(x, y)
+end
+
+function HotkeyBox:setSize(width, height)
+  self.button:setSize(width, height)
+end
+
+--================================
+--================================
+--================================
+
+--[[ Convert a static panel into a hotkeybox.
+! hotkeyboxes consist of the panel given as a parameter, which is made into a
+ToggleButton automatically, and handle keyboard input while active.
+!param panel (panel) The panel that will serve as the hotkeybox base.
+!param confirm_callback (function) The function to call when text is confirmed.
+!param abort_callback (function) The function to call when entering is aborted.
+]]
+function Window:makeHotkeyBoxOnPanel(panel, confirm_callback, abort_callback)
+  local hotkeybox = setmetatable({
+    panel = panel,
+    confirm_callback = confirm_callback,
+    abort_callback = abort_callback,
+    button = nil, -- placeholder
+    text = "",
+    allowed_input = {
+      alpha = true,
+      numbers = true,
+      misc = true,
+    },
+    char_limit = nil,
+    visible = true,
+    enabled = true,
+    active = false,
+    noted_keys = {},
+  }, hotkeybox_mt)
+
+  local button = panel:makeToggleButton(0, 0, panel.w, panel.h, nil, hotkeybox.clicked, hotkeybox)
+  hotkeybox.button = button
+
+  self.hotkeyboxes[#self.hotkeyboxes + 1] = hotkeybox
+  self.ui:registerHotkeyBox(hotkeybox)
+  return hotkeybox
+end
 
 function Window:draw(canvas, x, y)
   x, y = x + self.x, y + self.y
@@ -1303,6 +1472,11 @@ function Window:draw(canvas, x, y)
       box:drawCursor(canvas, x, y)
     end
   end
+  if not class.is(self, UI) then -- prevent UI (sub)class from handling the hotkeyboxes too
+    for _, _ in ipairs(self.hotkeyboxes) do
+      -- Empty right now. Don't know if I need it. -- LEIGET
+    end
+  end
   if self.windows then
     local windows = self.windows
     for i = #windows, 1, -1 do
@@ -1857,6 +2031,10 @@ function Window:afterLoad(old, new)
       btn.ui = self.ui
     end
   end
+  if old < 132 then
+    -- Hotkey boxes were added.
+    self.hotkeyboxes = {}
+  end
 
   if self.windows then
     for _, w in pairs(self.windows) do
